package com.qhtx.eta.init;

import com.qhtx.eta.domain.api.ApiServiceHolder;
import com.qhtx.eta.domain.api.http.ETAHttpClient;
import com.qhtx.eta.domain.enums.ETAInterfaceEnum;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * @description: 系统初始化api接口参数代理
 */
@Component
@Slf4j
public class ETAEnvironmentInit implements CommandLineRunner {

    @Resource
    private ApiServiceHolder apiServiceHolder;
    @Resource
    private ETAHttpClient httpClientHandler;


    @Override
    public void run(String... args) {
        log.info("============================ 初始化系统API接口 ============================");
        for (ETAInterfaceEnum etaInterfaceEnum : ETAInterfaceEnum.values()) {
            if (etaInterfaceEnum.getEnable()) {
                if (etaInterfaceEnum.getProxy() == null) {
                    log.info("接口{}无需参数代理", etaInterfaceEnum.name());
                    continue;
                }
                log.info("接口{}代理类{}", etaInterfaceEnum.name(), etaInterfaceEnum.getProxy().getName());
                apiServiceHolder.register(etaInterfaceEnum);
            }
        }
        // ETAHttpClient etaHttpClient = ETARetryProxyFactory.createProxy(httpClientHandler, ETAHttpClient.class);
        apiServiceHolder.registerClient(httpClientHandler);
        log.info("============================ 初始化系统API结束 ============================");
    }
}
